@@ -18,6 +18,10 @@ class FRAMEWORK:
     TORCH_GPU = "torch_gpu"
     KERAS = "keras"
     CAFFE = "caffe"
+    FURIOSA = "furiosa"
+    MmDetection = "mmdetection"
+    MmDetection_GPU = "mmdetection_gpu"
+    TF_RT = "tensort"
 
 
 # =====================================================================================================================
@@ -53,6 +57,22 @@ class DEVICE:
     class KERAS:
         CPU = "CPU"
 
+    class FURIOSA:
+        CPU = "CPU"
+        CUDA = "CUDA"
+        NPU = "NPU"
+
+    class MmDetection:
+        CPU = "CPU"
+
+    class MmDetection_GPU:
+        CPU = "CPU"
+        CUDA = "CUDA"
+
+    class TF_RT:
+        CPU = "CPU"
+        CUDA = "CUDA"
+
 
 # =====================================================================================================================
 SUPPORT_DEVICES = {
@@ -65,7 +85,11 @@ SUPPORT_DEVICES = {
         FRAMEWORK.TORCH: [DEVICE.TORCH.CPU],
         FRAMEWORK.TORCH_GPU: [DEVICE.TORCH.CPU, DEVICE.TORCH.CUDA],
         FRAMEWORK.CAFFE: [DEVICE.CAFFE.CPU],
-        FRAMEWORK.KERAS: [DEVICE.KERAS.CPU]
+        FRAMEWORK.KERAS: [DEVICE.KERAS.CPU],
+        FRAMEWORK.FURIOSA: [DEVICE.FURIOSA.CPU, DEVICE.FURIOSA.CUDA],
+        FRAMEWORK.MmDetection: [DEVICE.MmDetection.CPU],
+        FRAMEWORK.MmDetection_GPU: [DEVICE.MmDetection.CPU, DEVICE.MmDetection_GPU.CUDA],
+        FRAMEWORK.TF_RT: [DEVICE.TF_RT.CPU, DEVICE.TF_RT.CUDA]
     },
     ARCHITECTURE.AARCH64: {},
     ARCHITECTURE.ARMV7HF: {}
@@ -84,6 +108,7 @@ class MODEL_TYPE:
     TORCH = "TORCH"
     KERAS = "KERAS"
     CAFFE = "CAFFE"
+    TF_RT = "TF_RT"
 
 
 # =====================================================================================================================
