@@ -46,9 +46,9 @@ def get_text_size(draw, text, font, xy=(10, 10)):
         text_width = bbox[2] - bbox[0]
         text_height = bbox[3] - bbox[1]
 
-    # multi-line text
-    if "\n" in text:
-        text_height = text.count('\n') * text_height
+    # # multi-line text
+    # if "\n" in text:
+    #     text_height = text.count('\n') * text_height
     return text_width, text_height
 
 
@@ -86,30 +86,57 @@ def init_font(font_name=None, font_size=DEFAULT_FONT_SIZE):
 def put_text(
         draw,
         font,
-        bbox,  # tlwh
+        pos,  # tlwh
         text,
         text_color=DEFAULT_TXT_COLOR,
         align="left",
         large_padding=False,
-        bbox_thickness=-1,
-        bbox_color=None,
+        show_bg=False,  # background
+        bg_thickness=-1,
+        bg_color=DEFAULT_ROI_COLOR,
         show_shadow=False,
         shadow_color=DEFAULT_SHADOW_COLOR
 ):
-    text_width, text_height = get_text_size(draw=draw, text=text, font=font, xy=bbox[:2])
+    """
 
-    space = max(int(text_height // 8), 1)
+    Args:
+        draw: PIL.Draw object
+        font: font object to put text
+        pos: rectangle coordinates to put text - tlwh (x, y, w, h)
+        text: text string
+        text_color:
+        align: left or center
+        large_padding: information or title?
+        show_bg: True / False
+            show background(rectangle) or not
+        bg_color: DEFAULT_ROI_COLOR
+            RGBA color
+        bg_thickness: background(rectangle) thickness
+            if bck_thickness = -1: fill out rectangle with solid color
+            else: draw rectangle border with specified thickness
+        show_shadow:
+            True / False
+        shadow_color:
+            RGBA color
+
+    Returns:
+
+    """
+    text_width, text_height = get_text_size(draw=draw, text=text, font=font, xy=pos[:2])
+    num_lines = text.count("\n") + 1
+
+    space = max(int(text_height // num_lines // 8), 1)
     if large_padding:
-        padding_left = space * 4
-        padding_top = space * 2
+        padding_left = space * 8
+        padding_top = space * 4
     else:
         padding_left = space
         padding_top = space
 
-    if len(bbox) == 4:  # bbox
-        x, y, w, h = bbox[:4]
+    if len(pos) == 4:  # bbox
+        x, y, w, h = pos[:4]
     else:
-        x, y = bbox[:2]
+        x, y = pos[:2]
         w, h = text_width, text_height
 
     x1 = x
@@ -129,12 +156,12 @@ def put_text(
         x_text = x_cen_bbox - text_width // 2
         y_text = y_cen_bbox - text_height // 2
 
-    if bbox_color is not None:
-        if bbox_thickness == -1:
+    if show_bg:
+        if bg_thickness == -1:
             # put filled text rectangle
-            draw.rectangle(xy=[(x1, y1), (x2, y2)], fill=bbox_color)
+            draw.rectangle(xy=[(x1, y1), (x2, y2)], fill=bg_color)
         else:
-            draw.rectangle(xy=[(x1, y1), (x2, y2)], outline=bbox_color, width=bbox_thickness)
+            draw.rectangle(xy=[(x1, y1), (x2, y2)], outline=bg_color, width=bg_thickness)
     else:
         pass
 
