@@ -57,10 +57,11 @@ class VizObjectDraw:
                     utils.put_text(
                         font=self.default_font,
                         draw=draw,
-                        bbox=(x, y),
+                        pos=(x, y),
                         text=label,
-                        bbox_thickness=-1,
-                        bbox_color=bbox_color,
+                        show_bg=True,
+                        bg_thickness=-1,
+                        bg_color=bbox_color,
                         # show_shadow=True
                     )
 
